function [result] = M_compar_tbseuil_image(Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf)

%M_COMPAR_TBSEUIL_IMAGE boucle la fonction de comparaison EPSAT/MSG
%compar_tbseuil_image.m sur plusieurs jours.

%
%+
%
% ========================
% M_compar_tbseuil_image.m
% ========================
%
% .. function:: M_compar_tbseuil_image(Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf)
%
% DESCRIPTION
% ===========
%
% - Donnes d'entres :
%
%   * Tps_SeuilInf : Critre de temps minimum de vie d'un nuage pour qu'il
%     soit pris en compte (en nombre de quarts d'heure, 3 par dfaut).
%   * Tb_SeuilSup_ini : Seuil de temprature de brillance maximale
%     dlimitant un nuage convectif. Valeur de dpart pour la comparaison.
%   * dTb_SeuilSup : Variation du seuil de temprature de brillance des
%     nuages. Cette variation est applique  4 reprises.
%   * Tb_LimNoyau : Seuil de temprature de brillance dlimitant le noyau
%     dans notre modle  deux couches.
%
% boucle sur la fonction de comparaison EPSAT/MSG :func:`compar_tbseuil_image`
% sur plusieurs jours (la semaine d'tude est entre le 26 et le 31 juillet
% 2006).
%
% EXAMPLES
% ========
%
% Voir "demo".
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :ref:`data_epsat`
%
% :func:`compar_tbseuil_image`
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/M_compar_tbseuil_image.m $
%
% - fplod 20110830T074359Z cratos (Linux)
%
%   * suppress interactivity
%
% - jaclod 20110302
%
%   * Ajout de la doc et de la dmonstration
%
% - jaclod 20110226
%
%   * Cration
%
%-

result=-1;
usage='[result] = M_compar_tbseuil_image(Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
%%%%%%%%%%%%%
% Paramtres
%%%%%%%%%%%%%

% On se place dans le mois de Juillet 2006.
Annee = '2006';
Mois = '07';

%%%%%%%%%%%%%%%%%%%%%%%
% Boucle sur les jours
%%%%%%%%%%%%%%%%%%%%%%%

for jour = 26:31;

    % On enregistre la variable Jour sous forme 'string' pour la suite.
    Jour = num2str(jour);

    % On ouvre une nouvelle figure pour ce jour.
    figure;

    % On lance la fonction de comparaison d'images EPSAT / MSG pour ce jour
    % et pour les paramtres prcdemment dfinit.
    [Annee, Mois, Jour] = compar_tbseuil_image(Annee, Mois, Jour, Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf);

end

result=0;

end

%!demo
%! clear all
%! close all
%! varamma_startup;
%! Tb_SeuilSup_ini = 210;
%! dTb_SeuilSup = 10;
%! Tb_LimNoyau = 190;
%! Tps_SeuilInf = 3;
%! result = M_compar_tbseuil_image(Tb_SeuilSup_ini, dTb_SeuilSup, Tb_LimNoyau, Tps_SeuilInf);
