; docformat = 'rst'
;+
; .. _cloud_day.pro:
;
; =============
; cloud_day.pro
; =============
;
; DESCRIPTION
; ===========
;
; Programme d'analyse des nuages avec MSG  - version LE sur skylla
; identification des zones les plus convectives par jour, puis trace du
; hovmuller sur le mois
;
; les fichiers MSG sont des "images" ncdf tous les quarts d'heure.
;
; le but du programme est d'identifier les zones convectives
; (Tb<seuil en Kelvin) puis de chercher les nuages qui ont une duree
; de vie assez longue pour etre significatifs. Pour le moment
; j'ai pris 3/4 d'heure.  On garde en sortie les nuages selectionnes,
; comme indicateurs de l'activite convective de la journee
;
; SEE ALSO
; ========
;
; :ref:`guide data MSG <data_msg>`
;
; TODO
; ====
;
; ::
;
;  name='msg-tb108_2006-08-01_15min.nc'
;
;  is this program superseed :ref:`cloud_month.pro`.
;
;  build listmsg
;
;  octave migration
;
; EVOLUTIONS
; ==========
;
; $Id$
;
; $URL$
;
; - fplod 20110422T161737Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * create a pro
;   * prepare usage of PROJECT
;
; - fplod 20110118T160755Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal rst header
;
; - lelod 20110118
;
;   * commentaires pour Jason
;
;-
PRO cloud_day
;
@cm_project
;
name=''
nbjour=31
threshold=239.  ;seuil de Tb au dessus, nuage pas assez convectif (ne pleut pas ou peu)
; recherche des fichiers du mois
filemsg=project_id_env+'listmsg'
openr,1,filemsg, ERROR = error
IF (error NE 0) then begin
   ras = report(['eee : can not open for reading '$
         + '!C' $
         + 'code : ' + !ERROR_STATE.MSG $
         + filemsg])
   STOP
ENDIF
ijour=0
while not(eof(1)) do begin
   readf,1,name
   print,name
      ;name='msg-tb108_2006-08-13_15min.nc'
      ;name='msg-tb108_2006-07-01_15min.nc'
   file=path+name
   initncdf, file, xaxisname = 'longitude', yaxisname = 'latitude'
   lon1=-10 & lon2=-6 & lat1=0 & lat2=15    ; zone de travail (MSG couvre un domaine trop grand avec rsolution de 1 km
   h1=0 & h2=95 ; nb quarts d'heure (je ne sais pas lire la variable temps correctement)
   domdef,lon1,lon2,lat1,lat2
   data=read_ncdf('DATA',h1,h2,/timestep,timevar = 'time', file = file)
   date=strmid(name,50,50)
   s=size(data.arr,/DIMENSIONS)
   ni=s[0]
   ll=s[1]
   nbt=s[2]
   print,ni,ll,nbt
   ;initialisation des fichiers finaux
   if(ijour eq 0) then tbday=fltarr(ni,ll,nbjour)  ; tb moyenne pour le jour
   if(ijour eq 0) then kontday=intarr(ni,ll,nbjour)  ; nb de points cumulés dans le pixel
   ;boucle sur les quarts d'heure
   compt=intarr(ni,ll)          ;initialisation pour calcul des cumuls journaliers
   tb=fltarr(ni,ll)
   for itime=0,nbt-1 do begin
      tbmsg=smooth(data.arr(*,*,itime),10,/edge_truncate,/nan)  ; trop de détails, lissage pour simplifier
      bon=where(tbmsg gt 0,nbon)
      if (nbon ne 0) then begin
         clear=where(tbmsg gt threshold)
         tbmsg(clear)=0
         ;extraction des nuages
                                ;utilisation de la fonction idl qui
                                ;fait le travail toute seule!
                                ;sinon, j'ai un programme qui le fait
         cloud=tbmsg
         indnu=where(tbmsg ne 0,nbdetect)
         if (nbdetect ne 0) then cloud(indnu)=1
         nuag=label_region(cloud)
         numax=max(nuag)
         if(numax ne 0) then begin   ; on a trouve des nuages
         ;version calcul par nuage identifie:
            ; ichoix=1
             ;if (ichoix eq 1) then begin
                   for inu=1,numax do begin
                   zonu=where(nuag eq inu)
                   compt(zonu)=compt(zonu)+1
                   tb(zonu)=tb(zonu)+mean(tbmsg(zonu),/nan)
                   endfor
        endif
      endif
   endfor
;Moyennes et ecarts types pour la journee: on ne considere que les
;nuages qui sont vus plus d'un certain temps (nbkardeur)
   tbmoy=fltarr(ni,ll)
   nbkardeur=3
   indcloud=where(compt ge nbkardeur,nbcloud)
   if (nbcloud ne 0) then begin
      tbmoy(indcloud)=tb(indcloud)    ;/compt(indcloud)
  ; outcloud=where(compt lt nbkardeur)
  ; tbmoy(outcloud)=0
     ; window,1,xsize=300,ysize=500
     ;plt,tbmoy,/realcont,/cont_nofill,title='tb moy MSG',/rempli,/nocontour,min=min(tbmoy(indcloud))
     ; window,2,xsize=300,ysize=500
     ; plt,compt,/realcont,/cont_nofill,title='nb nuages MSG',/rempli,/nocontour,min=0,max=max(compt)
   endif
   tbday(*,*,ijour)=tbmoy
   kontday(*,*,ijour)=compt
   ijour=ijour+1
endwhile
h1=0 & h2=30
data=read_ncdf('DATA',h1,h2,/timestep,timevar = 'time', file = file)    ; test pour valider le programme
time=julday(07,1,2006)+lindgen(nbjour)
pltt,window=0,tbday,'yt',title='latitude - time MSG cloud Tb',/nocontour,/rempli
pltt,window=1,kontday,'yt',title='latitude - time MSG cloud number',/nocontour,/rempli,max=20

end
