#!/bin/sh
#
#+
#
#
# .. program:: extract_netcdf_TRMM.sh
#
# .. _extract_netcdf_TRMM.sh:
#
# ======================
# extract_netcdf_TRMM.sh
# ======================
#
# -----------------------------------
# Extract zone from NetCDF TRMM files
# -----------------------------------
#
# SYNOPSIS
# ========
#
# ::
#
#  extract_netcdf_TRMM.sh
#
# DESCRIPTION
# ===========
#
# Extract zone from NetCDF TRMM files.
#
# Input files are
# :file:`${PROJECT_ID}/TRMM/3B40/3B40RT.{yyyy}.{version}.nc`
#
#
# SEE ALSO
# ========
#
# :ref:`data_precipitation_microwave`
#
# Previous step : ++
#
# :func:`TRMMRread`
#
# TODO
# ====
#
# don't know hox Netcdf files have been produced :
# now longitude [-19.875,+9.875] latidute [+24.875 , +0.125]
#
# coding rules
#
# homogenize or merge with extract_zone_nc.sh
#
# create daily file
#
# EVOLUTIONS
# ==========
#
# - fplod 20110601T133702Z aedon.locean-ipsl.upmc.fr
#
#   * minimal header
#   * some consolidation
#
# - lelod 20110605
#
#   * creation
#
#-
yyyy=2006
version=5
lonmin=340.
lonmax=10.
latmin=0.
latmax=20.

# uncomment this line if you want to work with the official data tree
indir_base=${PROJECT_ID}/
# do not forget to comment the unofficial one
#indir_base=/homedata/eymard/
#
find_dir=${indir_base}/TRMM/3B40/
#
# find files
lesfiles=`find ${find_dir} -name "3B40RT.${yyyy}*.${version}.nc"`
#
if [ "${lesfiles}" = "" ]
then
   echo "iii : no files ${find_name} found under ${find_dir}"
   exit 0
fi
#
outdir="${PROJECT_ID}/TRMM/"
mkdir -p ${outdir}/tmp

for ifile in ${lesfiles}
do
  filename=$(basename ${ifile})
  newfile="extracted-${filename}"
  newfile2="extracted2-${filename}"
  echo "Extraction depuis ${filename}"
  ncks -O -h -d latitude,${latmin},${latmax} -d longitude,${lonmin},${lonmax} ${ifile} ${outdir}/tmp/${newfile}
  status=${?}
  if [ ${status} -ne 0 ]
  then
      echo "eee : pb with ncks on ${ifile}"
      ncdump -h ${ifile}
      exit 1
  else
      echo "iii : adding ${outdir}/tmp/${newfile}"
  fi
  unset status
  ncap2 -O -h -s '*nblon=$longitude.size;for (*idx=0;idx<nblon;idx++){if (longitude(idx) > 180) longitude(idx)=longitude(idx)-360.;}' ${outdir}/tmp/${newfile} ${outdir}/tmp/${newfile2}
  status=${?}
  if [ ${status} -ne 0 ]
  then
      echo "eee : pb with ncap2 on ${newfile}"
      ncdump -h ${newfile}
      exit 1
  else
      echo "iii : adding ${outdir}/tmp/${newfile2}"
  fi
  #++rm -f ${outdir}/tmp/${newfile}
done

#for imois in 01 02 03 04 05 06 07 08 09 10 11 12; do
#  ncrcat ${outdir}/tmp/extracted2-3B40RT.${yyyy}${imois}*.${version}.nc ${outdir}/tmp/extractedmois-3B40RT.${yyyy}${imois}.${version}.nc
#done
#ncrcat ${outdir}/tmp/extractedmois-3B40RT.${yyyy}*.${version}.nc ${outdir}/3B40RT.${yyyy}.${version}.nc

#[ -f ${outdir}/3B40RT.${yyyy}.${version}.nc ]&&{
#  rm -rf ${outdir}/tmp;
#}
