; docformat = 'rst'
;+
;
; .. get_sync_pulse.pro:
;
; ==================
; get_sync_pulse.pro
; ==================
;
; Returns a vector of the same length as the
; number of AMSU-B scanlines its values are:
;
;   i-th element of vector <pulse_line>:
;    n > 0  : AMSU-B scanline i is the first after a synch. pulse and
;             n is the coinciding AMSU-A scan
;    n = 0  : AMSU-B scanline i is either second or third scanline
;             after sync pulse
;
; ajout d'un test dans le cas ou on ne veut que amsub (use_amsua = 0), pour
; affecter a pulse_line toutes les lignes de amsub, sans tri
; relatif à l'ajustement au centre des pixels amsua
;
;  :Param:
;    descending
;      1: descending node 0: ascending node
;
; :Uses:
;
; :Restrictions:
;
; :Pre:
;
; :Post:
;
; :Todo:
;
; examples
;
; :Examples:
;
; ::
;   ++
;   get_sync_pulse, pulse_line,descending
;   print, pulse_line
;   print, descending
;
; :History:
;
;  $Id: get_sync_pulse.pro 257 2011-05-26 15:48:28Z pinsard $
;
; - eymard 21-11-2011 remis calcul "descending" dans cas amsub seul
;
; - pinsard 2011-05-16T13:09:29Z loholt1.ipsl.polytechnique.fr (Linux)
;
;   * compile opts
;
; - fplod 20100701T130054Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * minimal header
;
;-
PRO get_sync_pulse, use_amsua, pulse_line, descending
;
compile_opt idl2, strictarrsubs
;
if (use_amsua eq 0) then begin
   COMMON amsub_header,amb_head
   COMMON amsub_data  ,amb_scan
   blat0 = amb_scan.latlon[0,1]/1.E4
   blon0 = amb_scan.latlon[1,1]/1.E4
   pulse_line=indgen(N_ELEMENTS(blat0))
   IF (MOMENT(DERIV(blat0)))[0] GT 0 THEN descending =1 ELSE descending = 0
endif else begin
   COMMON amsua_header,ama_head
   COMMON amsua_data  ,ama_scan
   COMMON amsub_header,amb_head
   COMMON amsub_data  ,amb_scan
   alat0 = ama_scan.latlon[0,0]/1.E4
   alon0 = ama_scan.latlon[1,0]/1.E4
   blat0 = amb_scan.latlon[0,1]/1.E4
   blon0 = amb_scan.latlon[1,1]/1.E4
   IF (MOMENT(DERIV(alat0)))[0] GT 0 THEN descending =1 ELSE descending = 0
endelse
pulse_line=INTARR(N_ELEMENTS(blat0))
if use_amsua eq 1 then begin
   FOR i=0L,N_ELEMENTS(alat0)-1L DO BEGIN
    dist =SQRT ((alat0[i]-blat0)^2 + ((alon0[i]-blon0)*COS(!DTOR* alat0[i]))^2) *111.12
    ind =WHERE(dist EQ MIN(dist))
    pulse_line[ind[0]]=i+1
    ;PRINT,i,MIN(dist),alat0[i],alon0[i],blat0[ind[0]],blon0[ind[0]]
    ;print,i
    ; Simple test whether matching works
    ; IF MIN(dist) LT 15 OR MIN(dist GT 30)  THEN BEGIN
         ;   PRINT,'Error occured  while match AMSU-A/B files'
         ;  PRINT,' Distance between AMSU-B pixel [0,1] and AMSU-A pixel[0,*]'
         ; PRINT,' not in [15,..,30] km '
         ; PRINT,' Expected Value : ~21 km'
         ; PRINT,' Actual   Value : ',MIN(dist),' km'
         ; PRINT,' Are the files correct?'
    ; ENDIF
 ENDFOR
endif
END
