function [meandata, stddata] = meanandstdplot(data, dim1, dim2, dim3, nomvar)

%MEANANDSTDPLOT est une fonction permettant de realiser la carte des
%moyennes et ecart-types d'une variable dont les donnees sont inclus dans
%une matrice 3D dont les dimensions sont le temps, longitudes et latitudes.

%
%+
%
% =================
% meanandstdplot.m
% =================
%
% .. function:: meanandstdplot(data, dim1, dim2, dim3, nomvar)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * data : Matrice 3D dont les dimensions sont respectivement le temps,
%     longitudes et latitudes.
%   * dim1 : Variable de la dimension 1 de la matrice 'data', c'est-a-dire
%     le temps en jour julien.
%   * dim2 : Variable de la dimension 2 de la matrice 'data', c'est-a-dire
%     les longitudes.
%   * dim3 : Variable de la dimension 3 de la matrice 'data', c'est-a-dire
%     les latitudes.
%   * nomvar (caracteres) : Nom et unite de la donnee etudiee ici 
%     (Ex : 'cumuls EPSAT (mm)'). 
%
% - Donnees de sorties :
%
%   * meandata : Matrice 2D (longitudes, latitudes) comportant les donnees
%     moyennes sur le temps de la variable de la matrice 'data'.
%   * stddata : Matrice 2D (longitudes, latitudes) comportant les donnees
%     d'ecart-types sur le temps de la variable de la matrice 'data'.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/meanandstdplot.m $
%
% - fplod 20110830T074307Z cratos (Linux)
%
%   * suppress interactivity
%
% - jaclod 2011-07-27
%
%   * Ajout de la documentation, des commentaires et de la demonstration.
%
% - jaclod 2011-07-20
%
%   * Creation.
%
%-

usage='[meandata, stddata] = meanandstdplot(data, dim1, dim2, dim3, nomvar)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% Calculs de la moyenne et de l'ecart-type par rapport a la premiere
% dimension.
meandata = squeeze(mean(data,1));
stddata = squeeze(std(data,1));

% Creation de variables comportant les titres et noms des axes.
Title1 = ['Moyennes des ' nomvar ' du ' datestr(dim1(1),'dd mmm yyyy') ' au ' datestr(dim1(size(dim1,2)),'dd mmm yyyy')];
Title2 = ['Ecart-types des '  nomvar ' du ' datestr(dim1(1),'dd mmm yyyy') ' au ' datestr(dim1(size(dim1,2)),'dd mmm yyyy')];
Abs = 'Longitudes';
Ord = 'Latitudes';

% Ouverture d'une figure.
figure();

% Visualisation des donnees (il faut utiliser la transposee pour le
% 'imagesc' pour mettre la dimension 1, longitudes, sur l'axe des x).
subplot(1,2,1);
imagesc(dim2,dim3,meandata');
set(gca, 'DataAspectRatio', [1 1 1]);
set(gca,'ydir','normal');
title(Title1);
xlabel(Abs)
ylabel(Ord)
colorbar

subplot(1,2,2);
imagesc(dim2,dim3,stddata');
set(gca, 'DataAspectRatio', [1 1 1]);
set(gca,'ydir','normal');
title(Title2);
xlabel(Abs)
ylabel(Ord)
colorbar

end

%!demo
%! % school example
%! clear all
%! close all
%! data(1,:,:) = reshape(1:100,10,10);
%! for i = 2:50;
%!     data(i,:,:) = data(i-1,:,:)+2;
%! end
%! data = data+rand(50,10,10);
%! dim1 = datenum(2011,07,27) : datenum(2011,07,27)+49;
%! dim2 = -4.5:4.5;
%! dim3 = 0.5:9.5;
%! [meandata, stddata] = meanandstdplot(data, dim1, dim2, dim3, 'valeurs tests pour la demonstration');
