function [lai_mean, lai_std, aa_moy, aa_ecartype]=plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix, seuil)

%
%PLOT_LAI_GIS plot ++
%
%+
%
% ==============
% plot_lai_gis.m
% ==============
%
% .. function:: plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix)
%
% DESCRIPTION
% ===========
%
%    :param classes_select: classes we want to select ex: '"Savane herbacee et arbustive"'
%    :type classes_select: string
%    :raise classes_select: required
%
%    :param msdnom_select: msdnom we want to select ex: "FERRUGINEUX TROPICAUX"
%    :type msdnom_select: string
%    :raise msdnom_select: required
%
%    :param zi_code: zi_code zone where take data (!! no check is made here)
%    :type zi_code: string
%    :raise zi_code: required
%
%    :param imageprefix: string to be used at the beginning of the image file
%    :type imageprefix: string
%
%    :returns: 0 if ok or -1 if error
%    :rtype: integer
%
% If ``classes_select`` is empty (:samp:`''`), no critirium on classes_value
% value is applied to select data.
%
% If ``msdnom_select`` is empty (:samp:`''`), no critirium on msdnom_value
% value is applied to select data.
%
% If ``imageprefix`` is empty (:samp:`''`), no image is saved, else
% :file:`${PROJECT_OD}/{mageprefix}_{zi_code}_s{type_de_sol}_v{type_de_vegetation}.jpeg` is saved.
%
% EXAMPLES
% ========
%
% see demo
%
% SEE ALSO
% ========
%
% :ref:`data_lai`
% :ref:`zones`
%
% :func:`simul_lai_gis` ++
% :func:`read_lai_gis`
% :func:`select_lai_gis`
%
% called by :func:`graphe_zicode`
%
% use :func:`peakdet`
%
% TODO
% ====
%
% est-ce que index_juin est utilse si select_lai_gis a t 
% utilis?
%
% error bar instead of star on minima and maxima
%
% sur matlab on ne voit pas la courbe bleu : cache sous le jbfill ?
%
% aa_moy and aa_ecarttype are not computed anymore : why still in outputs ?
%
% why "x10^5" on matlab figure nearby X axis
%
% mme style de ligne pour toutes les courbes
%
% ajouter un mode de graphique en parametre pour superposer ou pas
%
% verifie l'argument seuil uint16
%
% zi_code ici en argument est utilis pour fabriquer le titre : il n'y a aucune
% vrificaton que les lat_value et lon_value correcpondent
% effectivement  cette zi !
%
% verifier que zi_code n'est pas vide si imageprefix n'est pas vide
%
% verifier que le calcul de aa_moy et de aa_ecartype doit bien tre 
% l'interieur de la boucle sur les pas de temps. cela peut remettre
% en cause l'initialisation de ces grandeurs
%
% add simulation demo
%
% coding rules
%
% check arg
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/plot_lai_gis.m $
%
% - fplod 20111115T113823Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add an example of select_lai_gis usage
%   * first and last month on x axis adjust to first and last 
%     month of data
%
% - fplod 20111115T084643Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add peak detection
%
% - soclod/lelod 201111??
%
%   * remove computation of aa_moy aa_ecarttype
%   * introduce index_juin for ??
%
% - fplod 20111104T103521Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * xtick on each 1st day of month
%   * remove yyyy forcing to 2008; yyyy is defined according 
%     to the first value of datejul_value input array
%   * restore figure incrementation
%
% - fplod 20111104T100039Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * avoid crash when matlab is running (no gcvspl available)
%     even if exists, need to change syntax of call because matlab does not
%     support argument syntax of this form result=myfunc(arg1=1).
%     prefer arg=1;result=myfunc(arg1).
%
% - fplod 20111103T140749Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix legend problem
%   * restore plot of ecart type
%
% - lelod 20111018
%
%   * add usage of gcvspl
%     for spline smoothing and second derivative
%
% - fplod 20110929T163627Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * resolution du pb de legende : si on a plusieurs courbes il n'y a qq'une
%     seule legende et c'est la legende de la derniere courbe qui apparait
%     thanks to http://www.mathworks.com/matlabcentral/newsreader/view_thread/168868 (seting userdata on each plot and get gca children info to define final
%     legend
%
% - fplod 20110929T144859Z cratos (Linux)
%
%   * suppression de classes dans le titre
%   * ajout de classes dans la legende
%   * ajout de nb de points dans la legende
%
% - soclod ??
%
%   * superposition de courbes
%   * changement de la legende et du titre
%
% - soclod/fplod 20110927
%
%   * add seuil parameter
%
% - fplod 20110923T074248Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * adjust message
%   * fix indentation
%
% - fplod 20110915T075353Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * suppress gridcode_value
%   * authorized no selection criteria on classes_value and msdom_value.
%     title of the figure is modified to see only non-empty criteria.
%     add 2 demos
%
% - fplod 20110909T141946Z cratos (Linux)
%
%   * save figure
%   * correction demo (more outputs)
%   * add parameter imageprefix
%
% - fplod 20110829T074158Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * aller  la ligne dans un titre
%   * tick label = dd/mm/yyyy (4 digigts for year)
%
% - fplod 20110823T132026Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace gricode and msd by classes_select and msdnom_select
%     to have more human readable software
%   * add check argument zi_code type
%
% - fplod 20110823T124532Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * allow successive calls without destroying existing figures
%
% - soclod 20110822
%
%   * add zi_code as paramater
%   * verification argument
%   * change demos
%
% - fplod/soclod 20110819
%
%   * remove hard coded title and xlabel values
%   * add init of aa_moy and aa_ecartype to avoid warning if
%     combinaison not found
%
% - soclod 20110818
%
%   * correction demo (more outputs)
%   * (fplod) pas de sortie en erreur si combinaison non trouve : un message
%     seulement
%
% - soclod 20110816
%
%   * add msd parameter
%   * add test of data found
%   * add demo with no data found
%
% - soclod 20110812
%
%   * ajout de sorties aa_moy et aa_ecartype les moyennes et ecart types filtres%
% - soclod/fplod 20110812T145149Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add and run demo with LAI2008F_veg2010_sol_barkedji.csv
%
% - fplod 20110812T140844Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * minimal header
%   * rehabilitaion of demo from real file with no zi
%   * replace la2008i_Clip_Intersect_Inter.csv by LAI2008F_veg2010_sol.csv
%   * replace num_classe by gridcode
%
%-
%
global application
global PROJECT_OD
%
usage='[lai_mean, lai_std, aa_moy, aa_ecartype]=plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('classes_select');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg classes_select ' arg_info.class]);
   whos classes_select
   error(usage);
end
clear arg_info
%
arg_info=whos('msdnom_select');
if ~strcmp(arg_info.class,'char')
   disp(['Incorrect type of arg msdnom_select ' arg_info.class]);
   whos msd
   error(usage);
end
clear arg_info
%
arg_info=whos('zi_code');
if ~strcmp(arg_info.class,'char')
    disp(['Incorrect type of arg zi_code ' arg_info.class]);
    whos zi_code
    error(usage);
end
clear arg_info
%
arg_info=whos('imageprefix');
if ~strcmp(arg_info.class,'char')
    disp(['Incorrect type of arg imageprefix ' arg_info.class]);
    whos imageprefix
    error(usage);
end
clear arg_info
%
% trace des lai moyens et ecart type pour une classe de vegetation
% choisie avec classes_select (tri dans le tableau classes_value) et avec
% msdnom_select (tri dans le tableau msdnom_value)
%
nb_doy= size(lai_value,1);
lai_mean=zeros(1,nb_doy);
lai_std=zeros(1,nb_doy);
aa_moy=zeros(1,nb_doy);
aa_ecartype=zeros(1,nb_doy);
%
% select asked data
% choix de la classe de vegetation et du type de sol
% if msdnom_select and classes_select are not empty, use both criteria
if (~isempty(msdnom_select) && ~isempty(classes_select))
    ind_value=find(strcmp(classes_value,classes_select) & strcmp(msdnom_value,msdnom_select));
elseif (~isempty(msdnom_select) && isempty(classes_select))
    ind_value=find(strcmp(msdnom_value,msdnom_select));
elseif (isempty(msdnom_select) && ~isempty(classes_select))
    ind_value=find(strcmp(classes_value,classes_select));
elseif (isempty(msdnom_select) && isempty(classes_select))
    ind_value=1:size(lai_value,2);
else
    disp(['eee : unknown combination of msdnom_select and classes_select to be found']);
    error(usage);
end
%
if isempty(ind_value);
    disp(['www : combinaison classes_select = ' classes_select ' and  msdnom_value = ' msdnom_select ' not found' ])
else
    aa=numel(ind_value);
    disp(['iii : nb point dans la combinaison ' classes_select ' ' msdnom_select ' vaut ' num2str(aa)])
    if (aa < seuil)
        disp(['iii : pas assez de points (' num2str(aa) ' < ' num2str(seuil) ' )'])
    else
       % calcul moyenne et ecart type
       % filtre des valeurs moyennes et des ecart types
       index_juin=20;
       for index_doy=1:nb_doy
           lai_mean(index_doy)=mean(lai_value(index_doy,ind_value));
           lai_std(index_doy)=std(lai_value(index_doy,ind_value));
          % p=5;
          % aa_moy=filter(ones(1,p)/p,1,lai_mean);
          % aa_ecartype=filter(ones(1,p)/p,1,lai_std);
       end
       % initialiaze a new figure
       ifigure=gcf()+1;
       figure(ifigure);
       % build legend
       malegende_p1='';
       if ~isempty(classes_select)
           %montitre=[montitre sprintf('classe : %s\n', classes_select)];
           malegende_p1=[malegende_p1 sprintf('%s', classes_select)];
       else
           malegende_p1=[malegende_p1 'toutes vegetations'];
       end
       if ~isempty(msdnom_select)
          %montitre= [montritre sprintf('type de sol : %s\n ', msdnom_select)];
          malegende_p1= [malegende_p1 sprintf(' - %s', msdnom_select)];
       else
          malegende_p1= [malegende_p1 ' - tous sols'];
       end
       malegende_p1=[malegende_p1 sprintf(' (%d points)', aa)];
       malegende_p2='spline';
       malegende_p3='derivee 2de de spline';
       malegende_p4='+/- ecart type';
       %
       % lissage de la moyenne par spline
       x=transpose(datejul_value);
       y=transpose(lai_mean);
       lai_var=lai_std.^2;
       varmean=mean(lai_var(index_juin:nb_doy));
       xk=transpose((varmean)./lai_var);
       switch application
           case {'matlab'}
              disp(['www : no gcvspl available using ', application]);
              laispw=[];
              laispw2=[];
           case {'octave'}
              gcvspl_arg6=[];
              xf=x;
              m=2;
              md=2;
              val=1;
              ider=[0];
              [laispw,wk]=gcvspl(x,y,xf,xk,gcvspl_arg6,m,md,val,ider);
              % spline pondere par l'inverse de la variance normalisee
              ider=[2];
              [laispw2,wk]=gcvspl(x,y,xf,xk,gcvspl_arg6,m,md,val,ider);
          otherwise
              error('eee : unknown application running');
       end
       hold on
       % trace des lai autour de la moyenne
       [p1,msg]=jbfill(datejul_value,lai_mean+lai_std,lai_mean-lai_std,[0.9 0.9 0.9],[1 1 1],.2);
       set(p1, 'userdata',malegende_p4);
       hold on
       p2=plot(datejul_value,aa_moy,'b-','linewidth',2);
       set(p2, 'userdata',malegende_p1);
       if ~isempty(laispw)
           hold on
           p3=plot(datejul_value,transpose(laispw),'r-','linewidth',3);
transpose(laispw)
           set(p3, 'userdata',malegende_p2);
           hold off
           hold on
           p4=plot(datejul_value,abs(transpose(laispw2*1000)),'k-','linewidth',1);
           set(p4, 'userdata',malegende_p3);
           x=datejul_value;
           y=abs(transpose(laispw2*1000));
           [maxtab, mintab] = peakdet(y, 0.01, x);
           disp([ '1er max a : ' datestr(maxtab(1,1)) '-'  num2str(maxtab(1,1))]);
           disp([ 'value 1er max : ' num2str(maxtab(1,2))]);
           hold off
           hold on
           p5=plot(mintab(:,1), mintab(:,2), 'g*');
           set(p5, 'userdata','min');
           hold off
           hold on
           p6=plot(maxtab(:,1), maxtab(:,2), 'r*');
           set(p6, 'userdata','max');
       end
       hold off
%
       xlabel(['jours (jj/mm) entre '  datestr_value(1,:) ' et ' datestr_value(end,:) ],'fontsize',16);
       ylabel('LAI','fontsize',16);
       yyyy=str2num(datestr(datejul_value(1),'yyyy'));
       mm_min=str2num(datestr(datejul_value(1),'mm'));
       mm_max=str2num(datestr(datejul_value(end),'mm'));
       set(gca,'xtick',datenum(yyyy,mm_min:mm_max+1,1))
       clear yyyy
       clear mm_min
       clear mm_max
       datetick('x','dd/mm','keepticks');
       montitre=sprintf('zi_code : %s\n', zi_code);
       %montitre=[montitre sprintf('nb de points : %d\n', aa)];
       title(montitre,'interpreter', 'none');
       ylim([0.1 2]);
       grid('on');
       %..collect labels from each curve and put up legend
       hc=get(gca,'children');
       s={};
       for h=hc'
           s={s{:},get(h,'userdata')};
       end
       legend(hc,s)
       % save figure
       if ~isempty(imageprefix)
           printer='jpeg';
           print_printer=['-d', printer];
           fullfilename=[PROJECT_OD imageprefix zi_code];
           if ~isempty(msdnom_select)
               s_infilename=regexprep(lower(msdnom_select),' ','_');
               s_infilename=regexprep(s_infilename,'"','');
               fullfilename=[fullfilename '_s' s_infilename];
           end
           if ~isempty(classes_select)
               v_infilename=regexprep(lower(classes_select),' ','_');
               v_infilename=regexprep(v_infilename,'"','');
               fullfilename=[fullfilename '_v' v_infilename];
           end
           fullfilename=[fullfilename '.' printer];
           clear printer;
           print(print_printer,fullfilename);
           clear print_printer;
           clear fullfilename;
      end
end

result=0;

end

%!demo
%! % To plot ++ on each point where
%! % classes is '"Savane herbacee et arbustive"' and msdnom is "LITHOSOLS"
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'ferlo';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! imageprefix= '';
%! classes_select = '"Savane herbacee et arbustive"';
%! msdnom_select = '"LITHOSOLS"';
%! seuil = uint16(10);
%! [lai_mean, lai_std, aa_moy, aa_ecartype] = plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value,classes_select, msdnom_select, zi_code, imageprefix, seuil)

%!demo
%! % To plot if exists on each point where
%! % classes is '"Savane herbacee et arbustive"' and msdnom is "LITHOSOLS"
%! % from the first 10 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%! % in this example no data found, so no plot
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! imageprefix= '';
%! classes_select = '"Savane herbacee et arbustive"';
%! msdnom_select = '"LITHOSOLS"';
%! seuil = uint16(100);
%! [lai_mean, lai_std, aa_moy, aa_ecartype] = plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix, seuil);

%!demo
%! % To plot ++ on each point where
%! % classes is '"Savane herbacee et arbustive"' and
%! % msdnom is "FERRUGINEUX TROPICAUX"
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%! % and produces an JPEG file in :file:`${PROJECT_OD}/lai_2008_barkedji_sferrugineux_tropicaux_vsavane_herbacee_et_arbustive.jpeg
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! imageprefix='lai_2008_'
%! classes_select = '"Savane herbacee et arbustive"';
%! msdnom_select = '"FERRUGINEUX TROPICAUX"';
%! seuil = uint16(10);
%! [lai_mean, lai_std, aa_moy, aa_ecartype] = plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix, seuil)

%!demo
%! % To plot ++ on each point where
%! % classes is '"Savane herbacee et arbustive"' and
%! % msdnom is "FERRUGINEUX TROPICAUX"
%! % and dates are between 20080601 and 20081231
%! % from the first 1000 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%! % and produces an JPEG file in :file:`${PROJECT_OD}/lai_2008_barkedji_sferrugineux_tropicaux_vsavane_herbacee_et_arbustive.jpeg
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(1000);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! yyyymmddb = 20080601;
%! yyyymmdde = 20081231;
%! [datejul_valueout, datestr_valueout, lai_valueout] = select_lai_gis(datejul_value, datestr_value, lai_value, yyyymmddb, yyyymmdde);
%! imageprefix='lai_2008_2s_'
%! classes_select = '"Savane herbacee et arbustive"';
%! msdnom_select = '"FERRUGINEUX TROPICAUX"';
%! seuil = uint16(10);
%! [lai_mean, lai_std, aa_moy, aa_ecartype] = plot_lai_gis(datejul_valueout, datestr_valueout, lai_valueout, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix, seuil) 
;
%!demo
%! % To plot if exists on each point where
%! % classes is '"Savane herbacee et arbustive"'
%! % from the first 10 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(10);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! imageprefix= '';
%! classes_select = '"Savane herbacee et arbustive"';
%! msdnom_select = '';
%! seuil = uint16(10);
%! [lai_mean, lai_std, aa_moy, aa_ecartype] = plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix, seuil)

%!demo
%! % To plot if exists on each point where
%! % msdnom is "FERRUGINEUX TROPICAUX"
%! % from the first 10 lines of real file
%! % :file:`${PROJECT_ID}/LAI_CVS/LAI2008F_veg2010_sol_barkeji.csv
%!
%! clear all
%! close all
%! varamma_startup
%! more off
%! yyyy = uint16(2008);
%! nbligne = uint16(0);
%! zi_code = 'barkedji';
%! [lon_value, lat_value, datejul_value, datestr_value, lai_value, classes_value, msdnom_value] = read_lai_gis(yyyy, nbligne, zi_code);
%! imageprefix= '';
%! classes_select = '';
%! msdnom_select = '"FERRUGINEUX TROPICAUX"';
%! seuil = uint16(100);
%! [lai_mean, lai_std, aa_moy, aa_ecartype] = plot_lai_gis(datejul_value, datestr_value, lai_value, classes_value, msdnom_value, classes_select, msdnom_select, zi_code, imageprefix, seuil);


% x=transpose(datejul_value);
% y=transpose(lai_mean);
% lai_var=lai_std.^2;
% varmean=mean(lai_var);
% xk=transpose((varmean)./lai_var);
% [laispw,wk]=gcvspl(x,y,xf=x,xk,[],m=2,md=2,val=1,ider=[0]);
% spline pondere par l'inverse de la variance normalisee
% [laispw2,wk]=gcvspl(x,y,xf=x,xk,[],m=2,md=2,val=1,ider=[2]);
% derivee seconde du spline pondere

% [laispl,wk]=gcvspl(x,y,xf=x,[],[],m=2,md=2,val=1,ider=[0]);
% spline sans ponderation
% [laispl2,wk]=gcvspl(x,y,xf=x,[],[],m=2,md=2,val=1,ider=[2]);
% derivee seconde du spline pondere

% p=plot(datejul_value,lai_mean,'k-','linewidth',2);
% hold on
% p=plot(datejul_value,transpose(laispl),'k--','linewidth',3);
% p=plot(datejul_value,transpose(laispw),'k:','linewidth',4);
% p=plot(datejul_value,transpose(laispl2*1000),'k-','linewidth',1);
% p=plot(datejul_value,transpose(laispw2*1000),'k-','linewidth',1);
%hold off

