function [yyyy, mm, dd] = split_yyyymmdd(yyyymmdd)

%SPLIT_YYYYMMDD split yyyymmdd (double) to yyyy, mm and dd
%
%+
%
% ================
% split_yyyymmdd.m
% ================
%
% .. function::  split_yyyymmdd(yyyymmdd)
%
% DESCRIPTION
% ===========
%
%    :param yyyymmdd: date in format yyyymmdd
%    :type yyyymmdd: double
%    :raise yyyymmdd: required
%
% ``split_yyyymmdd`` split the given date **yyyymmdd** into three double
% **yyyy**, **mm** and *dd**.
%
% Validity of date **yyyymmdd** is checked. If not ok, outputs are set to NULL.
%
% EXAMPLES
% ========
%
% see demos
%
% SEE ALSO
% ========
%
% TODO
% ====
%
% status de retour
%
% add test wtih assert and fail (octave)
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/split_yyyymmdd.m $
%
% - fplod 20110504T123644Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * adaptation to datevec differences between matlab and octave
%   * add tests
%
% - pinsard 2011-05-04T07:43:11Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * creation (to handle time loop) thanks to SAXO date2string
%
%-
%
global application
%
result=-1;
%
usage='[yyyy, mm, dd] = split_yyyymmdd(yyyymmdd)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('yyyymmdd');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg yyyymmdd ' arg_info.class]);
   whos yyyymmdd
   error(usage);
end
clear arg_info
%
dd=mod(yyyymmdd,100);
yyyymm=(yyyymmdd - dd)/100;
mm=mod(yyyymm,100);
yyyy=(yyyymm -mm)/100;
clear yyyymm
%
% compose yyyy-mm-dd string to check date validity
yyyymmdd_s=[num2str(yyyy,'%4.4d') '-' num2str(mm,'%2.2d') '-'  num2str(dd,'%2.2d')];
%
switch application
  case {'matlab'}
      date_datevec=datevec(yyyymmdd_s,'yyyy-mm-dd')
      if not((yyyy == date_datevec(1)) && (mm == date_datevec(2)) && (dd == date_datevec(3)))
         yyyy = -1;
         mm = -1;
         dd = -1;
         error(['eee : invalide date ' num2str(yyyymmdd,'%6.6d')]);
      end
   case {'octave'}
      try
         datevec(yyyymmdd_s,'yyyy-mm-dd');
      catch
         yyyy = -1;
         mm = -1;
         dd = -1;
         error(['eee : invalide date ' num2str(yyyymmdd,'%6.6d')]);
      end
  otherwise
     error('unknown application running');
end
%
clear date_datevec
clear yyyymmdd_s
%
clear usage
%
result=0;
%
end

%!demo
%! % demo ok
%! varamma_startup
%! yyyymmdd = 20060801;
%! [yyyy,mm,dd] = split_yyyymmdd(yyyymmdd)

%!demo
%! % demo pas ok
%! varamma_startup
%! yyyymmdd = 20060872;
%! [yyyy,mm,dd] = split_yyyymmdd(yyyymmdd)

%!test
%! % test ok
%! varamma_startup
%! yyyymmdd = 20060801;
%! [yyyy,mm,dd] = split_yyyymmdd(yyyymmdd);
%! assert(yyyy,2006)
%! assert(mm,08)
%! assert(dd,01)

%!test
%! % test pas ok
%! varamma_startup
%! yyyymmdd = 20060872;
%! fail('[yyyy,mm,dd] = split_yyyymmdd(yyyymmdd)','eee : invalide date 20060872')

